summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/spl-cast.h
diff options
context:
space:
mode:
authorChris Campbell <chriscampbell89@gmail.com>2013-12-09 12:41:17 +0000
committerChris Campbell <chriscampbell89@gmail.com>2013-12-10 15:37:22 +0000
commit9ff65a6a82d6c134e5ba0459042672e51d0cf3b5 (patch)
tree28aea7cf8bd59c2c5dafe4d877586c8fc901444f /crawl-ref/source/spl-cast.h
parent8fe954617de510e6e1666c5bf5f024c737d2ca4c (diff)
downloadcrawl-ref-9ff65a6a82d6c134e5ba0459042672e51d0cf3b5.tar.gz
crawl-ref-9ff65a6a82d6c134e5ba0459042672e51d0cf3b5.zip
Fix spelling of "targeting" (#7837)
See Mantis for discussion.
Diffstat (limited to 'crawl-ref/source/spl-cast.h')
-rw-r--r--crawl-ref/source/spl-cast.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/crawl-ref/source/spl-cast.h b/crawl-ref/source/spl-cast.h
index 7fbefdcf60..04dde33ff2 100644
--- a/crawl-ref/source/spl-cast.h
+++ b/crawl-ref/source/spl-cast.h
@@ -12,12 +12,12 @@
enum spflag_type
{
SPFLAG_NONE = 0x000000,
- SPFLAG_DIR_OR_TARGET = 0x000001, // use DIR_NONE targetting
- SPFLAG_TARGET = 0x000002, // use DIR_TARGET targetting
- SPFLAG_GRID = 0x000004, // use DIR_GRID targetting
- SPFLAG_DIR = 0x000008, // use DIR_DIR targetting
+ SPFLAG_DIR_OR_TARGET = 0x000001, // use DIR_NONE targeting
+ SPFLAG_TARGET = 0x000002, // use DIR_TARGET targeting
+ SPFLAG_GRID = 0x000004, // use DIR_GRID targeting
+ SPFLAG_DIR = 0x000008, // use DIR_DIR targeting
SPFLAG_TARG_OBJ = 0x000010, // use DIR_TARGET_OBJECT targ.
- SPFLAG_TARGETTING_MASK = 0x00001f, // used to test for targetting
+ SPFLAG_TARGETING_MASK = 0x00001f, // used to test for targeting
SPFLAG_HELPFUL = 0x000020, // TARG_FRIENDS used
SPFLAG_NEUTRAL = 0x000040, // TARG_ANY used
SPFLAG_NOT_SELF = 0x000080, // aborts on isMe